@@ -76,6 +76,12 @@ class TerminalController: BaseTerminalController {
             selector: #selector(onFrameDidChange),
             name: NSView.frameDidChangeNotification,
             object: nil)
+        center.addObserver(
+            self,
+            selector: #selector(onEqualizeSplits),
+            name: Ghostty.Notification.didEqualizeSplits,
+            object: nil
+        )
     }
 
     required init?(coder: NSCoder) {
@@ -212,6 +218,9 @@ class TerminalController: BaseTerminalController {
         // Set our explicit appearance if we need to based on the configuration.
         window.appearance = surfaceConfig.windowAppearance
 
+        // Update our window light/darkness based on our updated background color
+        window.isLightTheme = OSColor(surfaceConfig.backgroundColor).isLightColor
+
         // If our window is not visible, then we do nothing. Some things such as blurring
         // have no effect if the window is not visible. Ultimately, we'll have this called
         // at some point when a surface becomes focused.
@@ -801,6 +810,17 @@ class TerminalController: BaseTerminalController {
         toggleFullscreen(mode: fullscreenMode)
     }
 
+    @objc private func onEqualizeSplits(_ notification: Notification) {
+        guard let target = notification.object as? Ghostty.SurfaceView else { return }
+
+        // Check if target surface is in current controller's tree
+        guard surfaceTree?.contains(view: target) ?? false else { return }
+
+        if case .split(let container) = surfaceTree {
+            _ = container.equalize()
+        }
+    }
+
     struct DerivedConfig {
         let backgroundColor: Color
         let macosTitlebarStyle: String
